package com.nokia.dingtalkapi.service;

import java.util.ArrayList;
import java.util.List;

/**
 * 接口，定义对外开放的方法
 */
public interface DingtalkService {

    /**
     * 上传文件
     * 
     * @param filePath 文件本地路径
     * @param type     文件后缀 如 png xlsx等
     * @return 返回 media_id 用于在后续
     */
    String upload(String filePath, String type);

    /**
     * 发送图片消息
     * 
     * @param conversationId 群标识
     * @param mediaId        上传时得到的文件标识
     * @return 返回消息id可用于撤回已发送的消息
     */
    String sendImage(String conversationId, String mediaId);

    /**
     * 发送文件消息
     * 
     * @param conversationId 群标识
     * @param mediaId        上传时得到的文件标识
     * @param fileName       文件名
     * @return 消息id
     */
    String SendFile(String conversationId, String mediaId, String fileName);

    /**
     * 发送文本消息
     * 
     * @param conversationId
     * @param msg
     * @return
     */
    String SendText(String conversationId, String msg);

    /**
     * 发送markdown消息
     * 
     * @param conversationId
     * @param msg
     * @return
     */
    String sendMarkdown(String conversationId, String msg);

    /**
     * 批量撤回消息
     * https://open.dingtalk.com/document/orgapp/enterprise-chatbot-withdraws-internal-group-messages?spm=ding_open_doc.document.0.0.4c134a97XELzgK
     * 
     * @param conversationId
     * @param messageIdList
     */
    void recallMessage(String conversationId, List<String> messageIdList);

    default void recallMessage(String conversationId, String messageId) {
        recallMessage(conversationId, new ArrayList<String>() {
            {
                add(messageId);
            }
        });
    }
}
